/*
 *  Copyright 2000 by Hans Reiser, licensing governed by reiserfs/README
 */

#ifndef REISERFS_LIB_H
#define REISERFS_LIB_H

#include <reiserfs_fs.h>

struct _bitmap {
    unsigned long bm_size;
    char * bm_map;
};

typedef struct _bitmap reiserfs_bitmap_t;


struct _reiserfs_filsys {
    int version;		                  /* on-disk format version */
    reiserfs_bitmap_t * bitmap;			  /* copy of reiserfs on-disk bitmap */
    
    struct buffer_head * _super_block;		  /* buffer contains reiserfs on-disk super block */
    struct super_block * _vfs_super_block;        /* old vfs-like super block; used for compatibility with old
						     reiserfs-utils code */
};
typedef struct _reiserfs_filsys reiserfs_filsys_t;

/* reiserfslib.c */

reiserfs_filsys_t * reiserfs_open (char * filename, int flags);
void reiserfs_flush (reiserfs_filsys * fs);
void reiserfs_free (reiserfs_filsys * fs);
void reiserfs_close (reiserfs_filsys * fs);

/* bitmap.c */

reiserfs_bitmap_t * reiserfs_create_bitmap (unsigned int bit_count);
int reiserfs_expand_bitmap (reiserfs_bitmap_t * bm, unsigned int bit_count);
void reiserfs_delete_bitmap (reiserfs_bitmap_t * bm);
void reiserfs_bitmap_set_bit (reiserfs_bitmap_t * bm, unsigned int bit_number);
void reiserfs_bitmap_clear_bit (reiserfs_bitmap_t * bm, unsigned int bit_number);

int reiserfs_bitmap_test_bit (reiserfs_bitmap_t * bm, unsigned int bit_number);
int reiserfs_bitmap_find_zero_bit (reiserfs_bitmap_t * bm, unsigned int * start);
int reiserfs_fetch_bitmap_from_disk (reiserfs_bitmap_t * bm, reiserfs_filsys_t * fs);

#endif /* REISERFS_LIB_H */
